# Changelog

## [1.2.1] - 14/11/2025

### Added

- Added additional information to error messages, to help debugging/bug hunting

### Changed

- Update readme with details of sign up form to register for api access

## [1.2.0] - 13/11/2025

### Changed

- reduce minimum python version from `3.11` to `3.9`

### Fixed

- Bug that prevented `DCIR` simulations from running

## [1.1.0] - 02/10/2025

### Added

- Progress bar to show simulation progress
- Examples and utilities for performing Monte Carlo explorations of design variations.  See the example notebook `10 Manufacturing Variability.ipynb`

### Removed

- Incorrect cell and link in the example notebook `01 Getting Started.ipynb`

## [1.0.2] - 25/09/2025

### Fixed

- Fixed possible timeout when running a large number of simulations at once


## [1.0.0] - 16/09/2025

- Breathe Design is released.
